.. _sync_transports:

Sync Transports
================

Sync transports are transports which are using an underlying sync library.
They cannot be used asynchronously.

.. toctree::
   :maxdepth: 1

   requests
   httpx
